==> haskell-vector-instances-3.4-140-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-vector-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-instances
version: 3.4
id: vector-instances-3.4-1SWYJBAvQm7ArAdchUPg6a
key: vector-instances-3.4-1SWYJBAvQm7ArAdchUPg6a
license: BSD-3-Clause
maintainer: ekmett@gmail.com
author: Edward Kmett
homepage: http://github.com/ekmett/vector-instances
synopsis: Orphan Instances for '\''Data.Vector'\''
category: Data, Data Structures
abi: 39bb22c2a94bdf084c50abc02d1d25bd
exposed: True
exposed-modules:
    Data.Vector.Instances
import-dirs: /usr/lib/ghc-8.6.5/site-local/vector-instances-3.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/vector-instances-3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/vector-instances-3.4
hs-libraries: HSvector-instances-3.4-1SWYJBAvQm7ArAdchUPg6a
depends:
    base-4.12.0.0 comonad-5.0.5-CthxCPGmo5h60L0drN1HHd
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    keys-3.12.2-56ulPLO7StOIQ7D74wajlq
    pointed-5.0.1-HgaRs9vRF6i9YNfUynJ9oe
    semigroupoids-5.3.3-KFEReOTUWayAwY1pytSwUo
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock
haddock-html: /usr/share/doc/haskell-vector-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-instances-3.4-141-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-vector-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-instances
version: 3.4
id: vector-instances-3.4-FU52Z3T1hh0KeP9TNSsLWN
key: vector-instances-3.4-FU52Z3T1hh0KeP9TNSsLWN
license: BSD-3-Clause
maintainer: ekmett@gmail.com
author: Edward Kmett
homepage: http://github.com/ekmett/vector-instances
synopsis: Orphan Instances for '\''Data.Vector'\''
category: Data, Data Structures
abi: a79ca5cac43f12bbb4936fa8bd5b5f22
exposed: True
exposed-modules:
    Data.Vector.Instances
import-dirs: /usr/lib/ghc-8.6.5/site-local/vector-instances-3.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/vector-instances-3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/vector-instances-3.4
hs-libraries: HSvector-instances-3.4-FU52Z3T1hh0KeP9TNSsLWN
depends:
    base-4.12.0.0 comonad-5.0.5-4oKFRzjdJyn9LPwjAsvqPG
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    keys-3.12.2-1OCiWYkohvYELfOrux87tD
    pointed-5.0.1-6RJBKXDjyLe3GdifEFcavr
    semigroupoids-5.3.3-5c90p3ZZL5SEVl9HRh2nSh
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock
haddock-html: /usr/share/doc/haskell-vector-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
